from pickle import dumps, loads
from lzma import compress, decompress

def dump(variable, path):
    open(path, 'wb').write(compress(dumps(variable)))
    
def load(path):
    return loads(decompress(open(path, 'rb').read()))



from distutils.core import setup
setup(
  name = 'pklc',
  packages = ['pklc'],
  version = '0.4',
  license='MIT',
  description = 'lzma compressing pickles',
  author = 'msk_mule',
  author_email = '18.3071@gmail.com',
  keywords = ['pickle', 'compress', 'lzma'],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.8',
  ],
)
